@@ -41,7 +41,8 @@ namespace snapper
 
 
     void
-    command_debug(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers* snappers, ProxySnapper*)
+    command_debug(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers* snappers,
+		  ProxySnapper*, Plugins::Report& report)
     {
 	get_opts.parse("debug", GetOpts::no_options);
 	if (get_opts.has_args())
