@@ -24,6 +24,7 @@
 #include <iostream>
 
 #include "utils/text.h"
+#include "utils/help.h"
 #include "GlobalOptions.h"
 #include "proxy.h"
 #include "misc.h"
@@ -44,11 +45,11 @@ namespace snapper
 	cout << _("  Get config:") << '\n'
 	     << _("\tsnapper get-config") << '\n'
 	     << '\n'
-	     << _("    Options for 'get-config' command:") << '\n'
-	     << _("\t--columns <columns>\t\tColumns to show separated by comma.\n"
-		  "\t\t\t\t\tPossible columns: key, value.\n"
-		  "\t\t\t\t\tColumns are not selected when JSON format is used.") << '\n'
-	     << endl;
+	     << _("    Options for 'get-config' command:") << '\n';
+
+	print_options({
+	    { _("--columns <columns>"), _("Columns to show separated by comma.") }
+	});
     }
 
 
@@ -61,16 +62,16 @@ namespace snapper
 	};
 
 
-	pair<string, TableAlign>
+	Cell
 	header_for(Column column)
 	{
 	    switch (column)
 	    {
 		case Column::KEY:
-		    return make_pair(_("Key"), TableAlign::LEFT);
+		    return Cell(_("Key"));
 
 		case Column::VALUE:
-		    return make_pair(_("Value"), TableAlign::LEFT);
+		    return Cell(_("Value"));
 	    }
 
 	    SN_THROW(Exception("invalid column value"));
@@ -96,7 +97,7 @@ namespace snapper
 
 
 	void
-	output_table(const vector<Column>& columns, TableStyle style, ProxySnapper* snapper)
+	output_table(const vector<Column>& columns, Style style, ProxySnapper* snapper)
 	{
 	    TableFormatter formatter(style);
 
@@ -161,7 +162,8 @@ namespace snapper
 
 
     void
-    command_get_config(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers*, ProxySnapper* snapper)
+    command_get_config(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers*,
+		       ProxySnapper* snapper, Plugins::Report& report)
     {
 	const vector<Option> options = {
 	    Option("columns",	required_argument)
