@@ -24,6 +24,7 @@
 #include <iostream>
 
 #include "utils/text.h"
+#include "utils/help.h"
 #include "GlobalOptions.h"
 #include "proxy.h"
 #include "misc.h"
@@ -44,10 +45,11 @@ namespace snapper
 	cout << _("  List configs:") << '\n'
 	     << _("\tsnapper list-configs") << '\n'
 	     << '\n'
-	     << _("    Options for 'list-configs' command:\n"
-		  "\t--columns <columns>\t\tColumns to show separated by comma.\n"
-		  "\t\t\t\t\tPossible columns: config, subvolume.\n")
-	     << endl;
+	     << _("    Options for 'list-configs' command:") << '\n';
+
+	print_options({
+	    { _("--columns <columns>"), _("Columns to show separated by comma.") }
+	});
     }
 
 
@@ -60,16 +62,16 @@ namespace snapper
 	};
 
 
-	pair<string, TableAlign>
+	Cell
 	header_for(Column column)
 	{
 	    switch (column)
 	    {
 		case Column::CONFIG:
-		    return make_pair(_("Config"), TableAlign::LEFT);
+		    return Cell(_("Config"));
 
 		case Column::SUBVOLUME:
-		    return make_pair(_("Subvolume"), TableAlign::LEFT);
+		    return Cell(_("Subvolume"));
 	    }
 
 	    SN_THROW(Exception("invalid column value"));
@@ -95,7 +97,7 @@ namespace snapper
 
 
 	void
-	output_table(const vector<Column>& columns, TableStyle style, ProxySnappers* snappers)
+	output_table(const vector<Column>& columns, Style style, ProxySnappers* snappers)
 	{
 	    TableFormatter formatter(style);
 
@@ -167,7 +169,8 @@ namespace snapper
 
 
     void
-    command_list_configs(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers* snappers, ProxySnapper*)
+    command_list_configs(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers* snappers,
+			 ProxySnapper*, Plugins::Report& report)
     {
 	const vector<Option> options = {
 	    Option("columns",	required_argument)
