@@ -26,6 +26,7 @@
 #include <snapper/Filesystem.h>
 
 #include "utils/text.h"
+#include "utils/help.h"
 #include "GlobalOptions.h"
 #include "proxy.h"
 #include "misc.h"
@@ -43,19 +44,22 @@ namespace snapper
 	cout << _("  Modify snapshot:") << '\n'
 	     << _("\tsnapper modify <number>") << '\n'
 	     << '\n'
-	     << _("    Options for 'modify' command:") << '\n'
-	     << _("\t--description, -d <description>\tDescription for snapshot.") << '\n'
-	     << _("\t--cleanup-algorithm, -c <algo>\tCleanup algorithm for snapshot.") << '\n'
-	     << _("\t--userdata, -u <userdata>\tUserdata for snapshot.") << '\n'
-	     << _("\t--read-only\t\t\tSet snapshot read-only.") << '\n'
-	     << _("\t--read-write\t\t\tSet snapshot read-write.") << '\n'
-	     << _("\t--default\t\t\tSet snapshot as default snapshot.") << '\n'
-	     << endl;
+	     << _("    Options for 'modify' command:") << '\n';
+
+	print_options({
+	    { _("--description, -d <description>"), _("Description for snapshot.") },
+	    { _("--cleanup-algorithm, -c <algo>"), _("Cleanup algorithm for snapshot.") },
+	    { _("--userdata, -u <userdata>"), _("Userdata for snapshot.") },
+	    { _("--read-only"), _("Set snapshot read-only.") },
+	    { _("--read-write"), _("Set snapshot read-write.") },
+	    { _("--default"), _("Set snapshot as default snapshot.") },
+	});
     }
 
 
     void
-    command_modify(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers*, ProxySnapper* snapper)
+    command_modify(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers*,
+		   ProxySnapper* snapper, Plugins::Report& report)
     {
 	const vector<Option> options = {
 	    Option("description",		required_argument,	'd'),
@@ -126,7 +130,7 @@ namespace snapper
 
 	    if (set_smd)
 	    {
-		snapper->modifySnapshot(snapshot, smd);
+		snapper->modifySnapshot(snapshot, smd, report);
 	    }
 
 	    if (set_read_only)
@@ -138,7 +142,7 @@ namespace snapper
 	    {
 		ProxyConfig config = snapper->getConfig();
 		const Filesystem* filesystem = get_filesystem(config, global_options.root());
-		filesystem->setDefault(snapshot->getNum());
+		filesystem->setDefault(snapshot->getNum(), report);
 	    }
 	}
     }
