@@ -39,12 +39,13 @@ namespace snapper
     {
 	cout << _("  Setup quota:") << '\n'
 	     << _("\tsnapper setup-quota") << '\n'
-	     << endl;
+	     << '\n';
     }
 
 
     void
-    command_setup_quota(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers*, ProxySnapper* snapper)
+    command_setup_quota(GlobalOptions& global_options, GetOpts& get_opts, ProxySnappers*,
+			ProxySnapper* snapper, Plugins::Report& report)
     {
 	ParsedOpts opts = get_opts.parse("setup-quota", GetOpts::no_options);
 	if (get_opts.num_args() != 0)
