@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2020] SUSE LLC
+ * Copyright (c) [2016-2024] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -23,9 +23,12 @@
 
 #include "config.h"
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <iostream>
 
+#include <snapper/SystemCmd.h>
+#include <snapper/SnapperDefines.h>
+
 #include "utils/text.h"
 #include "utils/GetOpts.h"
 
@@ -43,6 +46,9 @@ using namespace std;
 // snapper-<name>.service'.
 
 
+Plugins::Report report;
+
+
 bool
 call_with_error_check(std::function<void()> func)
 {
@@ -77,7 +83,7 @@ timeline(ProxySnappers* snappers, const map<string, string>& userdata)
 	if (!proxy_config.is_yes("TIMELINE_CREATE"))
 	    continue;
 
-	cout << "running timeline for '" << value.first << "'." << endl;
+	cout << "Running timeline for '" << value.first << "'." << endl;
 
 	ProxySnapper* snapper = nullptr;
 
@@ -93,7 +99,7 @@ timeline(ProxySnappers* snappers, const map<string, string>& userdata)
 	scd.cleanup = "timeline";
 	scd.userdata = userdata;
 
-	if (!call_with_error_check([snapper, scd](){ snapper->createSingleSnapshot(scd); }))
+	if (!call_with_error_check([snapper, scd](){ snapper->createSingleSnapshot(scd, report); }))
 	{
 	    cerr << "timeline for '" << value.first << "' failed." << endl;
 	    ok = false;
@@ -107,6 +113,8 @@ timeline(ProxySnappers* snappers, const map<string, string>& userdata)
 bool
 cleanup(ProxySnappers* snappers)
 {
+    const bool verbose = true;
+
     bool ok = true;
 
     map<string, ProxyConfig> configs = snappers->getConfigs();
@@ -121,7 +129,7 @@ cleanup(ProxySnappers* snappers)
 	if (!do_number && !do_timeline && !do_empty_pre_post)
 	    continue;
 
-	cout << "running cleanup for '" << value.first << "'." << endl;
+	cout << "Running cleanup for '" << value.first << "'." << endl;
 
 	ProxySnapper* snapper = nullptr;
 
@@ -134,9 +142,9 @@ cleanup(ProxySnappers* snappers)
 
 	if (do_number)
 	{
-	    cout << "running number cleanup for '" << value.first << "'." << endl;
+	    cout << "Running number cleanup for '" << value.first << "'." << endl;
 
-	    if (!call_with_error_check([snapper](){ do_cleanup_number(snapper, false); }))
+	    if (!call_with_error_check([snapper](){ do_cleanup_number(snapper, verbose, report); }))
 	    {
 		cerr << "number cleanup for '" << value.first << "' failed." << endl;
 		ok = false;
@@ -145,9 +153,9 @@ cleanup(ProxySnappers* snappers)
 
 	if (do_timeline)
 	{
-	    cout << "running timeline cleanup for '" << value.first << "'." << endl;
+	    cout << "Running timeline cleanup for '" << value.first << "'." << endl;
 
-	    if (!call_with_error_check([snapper](){ do_cleanup_timeline(snapper, false); }))
+	    if (!call_with_error_check([snapper](){ do_cleanup_timeline(snapper, verbose, report); }))
 	    {
 		cerr << "timeline cleanup for '" << value.first << "' failed." << endl;
 		ok = false;
@@ -156,14 +164,36 @@ cleanup(ProxySnappers* snappers)
 
 	if (do_empty_pre_post)
 	{
-	    cout << "running empty-pre-post cleanup for '" << value.first << "'." << endl;
+	    cout << "Running empty-pre-post cleanup for '" << value.first << "'." << endl;
 
-	    if (!call_with_error_check([snapper](){ do_cleanup_empty_pre_post(snapper, false); }))
+	    if (!call_with_error_check([snapper](){ do_cleanup_empty_pre_post(snapper, verbose, report); }))
 	    {
 		cerr << "empty-pre-post cleanup for " << value.first << " failed." << endl;
 		ok = false;
 	    }
 	}
+
+	string fstype;
+	if (proxy_config.getValue(KEY_FSTYPE, fstype) && fstype == "btrfs")
+	{
+	    string subvolume;
+	    if (proxy_config.getValue(KEY_SUBVOLUME, subvolume))
+	    {
+		string general_dir = (subvolume == "/" ? "" : subvolume) + "/" SNAPSHOTS_NAME;
+
+		cout << "Running 'btrfs qgroup clear-stale " << general_dir << "'." << endl;
+
+		SystemCmd cmd({ BTRFS_BIN, "qgroup", "clear-stale", general_dir });
+		if (cmd.retcode() != 0)
+		{
+		    // This fails more often than not since qgroups of just deleted
+		    // subvolume are busy. So do not set an error code here. Still log the
+		    // failure to help people understand this stuff.
+
+		    cerr << "'btrfs qgroup clear-stale " << general_dir << "' failed." << endl;
+		}
+	    }
+	}
     }
 
     return ok;
@@ -228,5 +258,14 @@ main(int argc, char** argv)
 	ok = false;
     }
 
+    for (const Plugins::Report::Entry& entry : report.entries)
+    {
+	if (entry.exit_status != 0)
+	{
+	    cerr << "server-side plugin '" << entry.name << "' failed\n";
+	    ok = false;
+	}
+    }
+
     exit(ok ? EXIT_SUCCESS : EXIT_FAILURE);
 }
