@@ -1,5 +1,5 @@
 /*
- * Copyright (c) [2019-2020] SUSE LLC
+ * Copyright (c) [2019-2024] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -29,26 +29,24 @@ namespace snapper
     using namespace std;
 
 
-    const TableStyle TableFormatter::default_style = Ascii;
-
-
     ostream&
     operator<<(ostream& stream, const TableFormatter& table_formatter)
     {
-	Table table;
+	Table table(table_formatter._header);
+
 	table.set_style(table_formatter.style);
 
-	TableHeader table_header;
+	for (Id id : table_formatter._abbreviate)
+	    if (table.has_id(id))
+		table.set_abbreviate(id, true);
 
-	for (const pair<string, TableAlign>& column : table_formatter._header)
-	    table_header.add(column.first, column.second);
-
-	table.setHeader(table_header);
-	table.set_abbrev(table_formatter._abbrev);
+	for (Id id : table_formatter._trim)
+	    if (table.has_id(id))
+		table.set_trim(id, true);
 
 	for (const vector<string>& row : table_formatter._rows)
 	{
-	    TableRow table_row;
+	    Table::Row table_row(table);
 
 	    for (const string& value : row)
 		table_row.add(value);
