@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2012-2015] Novell, Inc.
- * Copyright (c) [2016-2023] SUSE LLC
+ * Copyright (c) [2016-2024] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -127,21 +127,23 @@ Client::delete_comparison(list<Comparison*>::iterator it)
 void
 Client::add_lock(const string& config_name)
 {
-    locks.insert(config_name);
+    locks[config_name]++;
 }
 
 
 void
 Client::remove_lock(const string& config_name)
 {
-    locks.erase(config_name);
+    map<string, unsigned int>::iterator it = locks.find(config_name);
+    if (it != locks.end() && --it->second == 0)
+	locks.erase(it);
 }
 
 
 bool
 Client::has_lock(const string& config_name) const
 {
-    return contains(locks, config_name);
+    return locks.find(config_name) != locks.end();
 }
 
 
@@ -399,6 +401,13 @@ Client::introspect(DBus::Connection& conn, DBus::Message& msg)
 	"      <arg name='config-name' type='s' direction='in'/>\n"
 	"    </method>\n"
 
+	"    <method name='GetPluginsReport'>\n"
+	"      <arg name='report' type='a(sasi)' direction='out'/>\n"
+	"    </method>\n"
+
+	"    <method name='ClearPluginsReport'>\n"
+	"    </method>\n"
+
 	"  </interface>\n"
 	"</node>\n";
 
@@ -682,7 +691,7 @@ Client::create_config(DBus::Connection& conn, DBus::Message& msg)
 
     check_permission(conn, msg);
 
-    meta_snappers.createConfig(config_name, subvolume, fstype, template_name);
+    meta_snappers.createConfig(config_name, subvolume, fstype, template_name, report);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -710,7 +719,7 @@ Client::delete_config(DBus::Connection& conn, DBus::Message& msg)
     check_lock(conn, msg, config_name);
     check_config_in_use(*it);
 
-    meta_snappers.deleteConfig(it);
+    meta_snappers.deleteConfig(it, report);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -891,7 +900,7 @@ Client::set_snapshot(DBus::Connection& conn, DBus::Message& msg)
     if (snap == snapshots.end())
 	SN_THROW(IllegalSnapshotException());
 
-    snapper->modifySnapshot(snap, smd);
+    snapper->modifySnapshot(snap, smd, report);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -922,7 +931,7 @@ Client::create_single_snapshot(DBus::Connection& conn, DBus::Message& msg)
 
     Snapper* snapper = it->getSnapper();
 
-    Snapshots::iterator snap1 = snapper->createSingleSnapshot(scd);
+    Snapshots::iterator snap1 = snapper->createSingleSnapshot(scd, report);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -961,7 +970,7 @@ Client::create_single_snapshot_v2(DBus::Connection& conn, DBus::Message& msg)
 
     Snapshots::iterator parent = snapshots.find(parent_num);
 
-    Snapshots::iterator snap2 = snapper->createSingleSnapshot(parent, scd);
+    Snapshots::iterator snap2 = snapper->createSingleSnapshot(parent, scd, report);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -995,7 +1004,7 @@ Client::create_single_snapshot_of_default(DBus::Connection& conn, DBus::Message&
 
     Snapper* snapper = it->getSnapper();
 
-    Snapshots::iterator snap = snapper->createSingleSnapshotOfDefault(scd);
+    Snapshots::iterator snap = snapper->createSingleSnapshotOfDefault(scd, report);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -1029,7 +1038,7 @@ Client::create_pre_snapshot(DBus::Connection& conn, DBus::Message& msg)
 
     Snapper* snapper = it->getSnapper();
 
-    Snapshots::iterator snap1 = snapper->createPreSnapshot(scd);
+    Snapshots::iterator snap1 = snapper->createPreSnapshot(scd, report);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -1067,12 +1076,16 @@ Client::create_post_snapshot(DBus::Connection& conn, DBus::Message& msg)
 
     Snapshots::iterator snap1 = snapshots.find(pre_num);
 
-    Snapshots::iterator snap2 = snapper->createPostSnapshot(snap1, scd);
+    Snapshots::iterator snap2 = snapper->createPostSnapshot(snap1, scd, report);
 
     bool background_comparison = true;
     it->getConfigInfo().get_value("BACKGROUND_COMPARISON", background_comparison);
     if (background_comparison)
-	clients.backgrounds().add_task(it, snap1, snap2);
+    {
+	// TODO isReadOnly is wrong if read-only is not supported by file system
+	if (snap1->isReadOnly() && snap2->isReadOnly())
+	    clients.backgrounds().add_task(it, snap1, snap2);
+    }
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -1113,7 +1126,7 @@ Client::delete_snapshots(DBus::Connection& conn, DBus::Message& msg)
 
 	Snapshots::iterator snap = snapshots.find(*it2);
 
-	snapper->deleteSnapshot(snap);
+	snapper->deleteSnapshot(snap, report);
     }
 
     DBus::MessageMethodReturn reply(msg);
@@ -1708,6 +1721,8 @@ Client::sync(DBus::Connection& conn, DBus::Message& msg)
 
     y2deb("Sync config_name:" << config_name);
 
+    boost::unique_lock<boost::shared_mutex> lock(big_mutex);
+
     MetaSnappers::iterator it = meta_snappers.find(config_name);
 
     check_permission(conn, msg, *it);
@@ -1722,6 +1737,43 @@ Client::sync(DBus::Connection& conn, DBus::Message& msg)
 }
 
 
+void
+Client::get_plugins_report(DBus::Connection& conn, DBus::Message& msg)
+{
+    y2deb("GetPluginsReport");
+
+    boost::unique_lock<boost::shared_mutex> lock(big_mutex);
+
+    // No permission check here: The report belongs to the client.
+
+    DBus::MessageMethodReturn reply(msg);
+
+    DBus::Marshaller marshaller(reply);
+    marshaller << report.entries;
+
+    conn.send(reply);
+}
+
+
+void
+Client::clear_plugins_report(DBus::Connection& conn, DBus::Message& msg)
+{
+    y2deb("ClearPluginsReport");
+
+    boost::unique_lock<boost::shared_mutex> lock(big_mutex);
+
+    // No permission check here: The report belongs to the client.
+
+    DBus::MessageMethodReturn reply(msg);
+
+    report.clear();
+
+    DBus::Marshaller marshaller(reply);
+
+    conn.send(reply);
+}
+
+
 void
 Client::debug(DBus::Connection& conn, DBus::Message& msg)
 {
@@ -1788,6 +1840,7 @@ Client::debug(DBus::Connection& conn, DBus::Message& msg)
     marshaller << "    version " + string(Snapper::compileVersion());
     marshaller << "    libversion " LIBSNAPPER_MAJOR "." LIBSNAPPER_MINOR "." LIBSNAPPER_PATCHLEVEL;
     marshaller << "    flags " + string(Snapper::compileFlags());
+    marshaller << "    CONF_DIR " CONF_DIR;
 
     marshaller.close_array();
 
@@ -1836,6 +1889,8 @@ Client::dispatch(DBus::Connection& conn, DBus::Message& msg)
 	{ "QueryQuota", &Client::query_quota },
 	{ "QueryFreeSpace", &Client::query_free_space },
 	{ "Sync", &Client::sync },
+	{ "GetPluginsReport", &Client::get_plugins_report },
+	{ "ClearPluginsReport", &Client::clear_plugins_report },
 	{ "Debug", &Client::debug }
     };
 
@@ -1942,6 +1997,12 @@ Client::dispatch(DBus::Connection& conn, DBus::Message& msg)
 	DBus::MessageError reply(msg, "error.delete_snapshot_failed", DBUS_ERROR_FAILED);
 	conn.send(reply);
     }
+    catch (const InvalidConfigException& e)
+    {
+	SN_CAUGHT(e);
+	DBus::MessageError reply(msg, "error.invalid_config", DBUS_ERROR_FAILED);
+	conn.send(reply);
+    }
     catch (const InvalidConfigdataException& e)
     {
 	SN_CAUGHT(e);
@@ -2174,7 +2235,7 @@ Client::files_transfer_worker()
 	    catch (const StreamException& e)
 	    {
 		SN_CAUGHT(e);
-		y2err("error occured during files transfer");
+		y2err("error occurred during files transfer");
 	    }
 	}
     }
