@@ -50,7 +50,7 @@ namespace snapper
 	if (fstype == "ext4")
 	    return new Ext4(subvolume, root_prefix);
 
-	return NULL;
+	return nullptr;
     }
 
 
@@ -88,10 +88,10 @@ namespace snapper
     void
     Ext4::createConfig() const
     {
-	int r1 = mkdir((subvolume + "/.snapshots").c_str(), 0700);
+	int r1 = mkdir((subvolume + "/" SNAPSHOTS_NAME).c_str(), 0700);
 	if (r1 == 0)
 	{
-	    SystemCmd cmd1(CHATTRBIN " +x " + quote(subvolume + "/.snapshots"));
+	    SystemCmd cmd1({ CHATTRBIN, "+x", subvolume + "/" SNAPSHOTS_NAME });
 	    if (cmd1.retcode() != 0)
 		throw CreateConfigFailedException("chattr failed");
 	}
@@ -101,10 +101,10 @@ namespace snapper
 	    throw CreateConfigFailedException("mkdir failed");
 	}
 
-	int r2 = mkdir((subvolume + "/.snapshots/.info").c_str(), 0700);
+	int r2 = mkdir((subvolume + "/" SNAPSHOTS_NAME "/.info").c_str(), 0700);
 	if (r2 == 0)
 	{
-	    SystemCmd cmd2(CHATTRBIN " -x " + quote(subvolume + "/.snapshots/.info"));
+	    SystemCmd cmd2({ CHATTRBIN, "-x", subvolume + "/" SNAPSHOTS_NAME "/.info" });
 	    if (cmd2.retcode() != 0)
 		throw CreateConfigFailedException("chattr failed");
 	}
@@ -119,14 +119,14 @@ namespace snapper
     void
     Ext4::deleteConfig() const
     {
-	int r1 = rmdir((subvolume + "/.snapshots/.info").c_str());
+	int r1 = rmdir((subvolume + "/" SNAPSHOTS_NAME "/.info").c_str());
 	if (r1 != 0)
 	{
 	    y2err("rmdir failed errno:" << errno << " (" << stringerror(errno) << ")");
 	    throw DeleteConfigFailedException("rmdir failed");
 	}
 
-	int r2 = rmdir((subvolume + "/.snapshots").c_str());
+	int r2 = rmdir((subvolume + "/" SNAPSHOTS_NAME).c_str());
 	if (r2 != 0)
 	{
 	    y2err("rmdir failed errno:" << errno << " (" << stringerror(errno) << ")");
@@ -145,7 +145,7 @@ namespace snapper
     string
     Ext4::snapshotFile(unsigned int num) const
     {
-	return (subvolume == "/" ? "" : subvolume) + "/.snapshots/" + decString(num);
+	return (subvolume == "/" ? "" : subvolume) + "/" SNAPSHOTS_NAME "/" + decString(num);
     }
 
 
@@ -174,11 +174,11 @@ namespace snapper
 	if (num_parent != 0 || !read_only)
 	    throw std::logic_error("not implemented");
 
-	SystemCmd cmd1(TOUCHBIN " " + quote(snapshotFile(num)));
+	SystemCmd cmd1({ TOUCHBIN, snapshotFile(num) });
 	if (cmd1.retcode() != 0)
 	    throw CreateSnapshotFailedException();
 
-	SystemCmd cmd2(CHSNAPBIN " +S " + quote(snapshotFile(num)));
+	SystemCmd cmd2({ CHSNAPBIN, "+S", snapshotFile(num) });
 	if (cmd2.retcode() != 0)
 	    throw CreateSnapshotFailedException();
     }
@@ -187,7 +187,7 @@ namespace snapper
     void
     Ext4::deleteSnapshot(unsigned int num) const
     {
-	SystemCmd cmd(CHSNAPBIN " -S " + quote(snapshotFile(num)));
+	SystemCmd cmd({ CHSNAPBIN, "-S", snapshotFile(num) });
 	if (cmd.retcode() != 0)
 	    throw DeleteSnapshotFailedException();
     }
@@ -212,7 +212,7 @@ namespace snapper
 	if (isSnapshotMounted(num))
 	    return;
 
-	SystemCmd cmd1(CHSNAPBIN " +n " + quote(snapshotFile(num)));
+	SystemCmd cmd1({ CHSNAPBIN, "+n", snapshotFile(num) });
 	if (cmd1.retcode() != 0)
 	    throw MountSnapshotFailedException();
 
@@ -237,7 +237,7 @@ namespace snapper
 	// if (!umount(snapshotDir(num)))
 	// throw UmountSnapshotFailedException();
 
-	SystemCmd cmd1(CHSNAPBIN " -n " + quote(snapshotFile(num)));
+	SystemCmd cmd1({ CHSNAPBIN, "-n", snapshotFile(num) });
 	if (cmd1.retcode() != 0)
 	    throw UmountSnapshotFailedException();
 
