@@ -23,9 +23,9 @@
 
 #include <pwd.h>
 #include <unistd.h>
-#include <string.h>
+#include <cstring>
 #include <sys/types.h>
-#include <libxml/tree.h>
+#include <libxml/xmlerror.h>
 #include <string>
 #include <boost/thread.hpp>
 
