@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2004-2014] Novell, Inc.
- * Copyright (c) [2020-2023] SUSE LLC
+ * Copyright (c) [2020-2024] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -43,10 +43,19 @@
 #define DEV_MAPPER_DIR "/dev/mapper"
 
 
+// parts of the path of snapshots
+// "/.snapshots/42/snapshot/" = "/SNAPSHOTS_NAME/42/snapshot/"
+
+#define SNAPSHOTS_NAME ".snapshots"
+#define SNAPSHOT_NAME "snapshot"
+
+
 // commands
 
 #define SH_BIN "/bin/sh"
 
+#define BTRFS_BIN "/usr/sbin/btrfs"
+
 #define SYSTEMCTL_BIN "/usr/bin/systemctl"
 
 
