@@ -43,13 +43,14 @@
 #include "snapper/SnapperTmpl.h"
 #include "snapper/SnapperDefines.h"
 #include "snapper/Exception.h"
-#include "snapper/Hooks.h"
+#include "snapper/PluginsImpl.h"
 #include "snapper/ComparisonImpl.h"
 
 
 namespace snapper
 {
     using std::list;
+    using std::regex;
 
 
     std::ostream& operator<<(std::ostream& s, const Snapshot& snapshot)
@@ -86,9 +87,7 @@ namespace snapper
     }
 
 
-    Snapshot::~Snapshot()
-    {
-    }
+    Snapshot::~Snapshot() = default;
 
 
     // Directory containing the actual content of the snapshot.
@@ -162,7 +161,15 @@ namespace snapper
     void
     Snapshot::setDefault() const
     {
-	snapper->getFilesystem()->setDefault(num);
+	Plugins::Report report;
+	setDefault(report);
+    }
+
+
+    void
+    Snapshot::setDefault(Plugins::Report& report) const
+    {
+	snapper->getFilesystem()->setDefault(num, report);
     }
 
 
@@ -205,7 +212,7 @@ namespace snapper
     {
 	SDir info_dir = openInfoDir();
 
-	// remove all filelists in the info directory of this shapshot
+	// remove all filelists in the info directory of this snapshot
 	for (const string& name : info_dir.entries(is_filelist_file))
 	{
 	    info_dir.unlink(name, 0);
@@ -231,9 +238,7 @@ namespace snapper
     }
 
 
-    Snapshots::~Snapshots()
-    {
-    }
+    Snapshots::~Snapshots() = default;
 
 
     void
@@ -666,7 +671,7 @@ namespace snapper
 
 
     Snapshots::iterator
-    Snapshots::createSingleSnapshot(const SCD& scd)
+    Snapshots::createSingleSnapshot(const SCD& scd, Plugins::Report& report)
     {
 	checkUserdata(scd.userdata);
 
@@ -677,12 +682,12 @@ namespace snapper
 	snapshot.cleanup = scd.cleanup;
 	snapshot.userdata = scd.userdata;
 
-	return createHelper(snapshot, getSnapshotCurrent(), scd.empty);
+	return createHelper(snapshot, getSnapshotCurrent(), scd.empty, report);
     }
 
 
     Snapshots::iterator
-    Snapshots::createSingleSnapshot(const_iterator parent, const SCD& scd)
+    Snapshots::createSingleSnapshot(const_iterator parent, const SCD& scd, Plugins::Report& report)
     {
 	checkUserdata(scd.userdata);
 
@@ -693,12 +698,12 @@ namespace snapper
 	snapshot.cleanup = scd.cleanup;
 	snapshot.userdata = scd.userdata;
 
-	return createHelper(snapshot, parent);
+	return createHelper(snapshot, parent, false, report);
     }
 
 
     Snapshots::iterator
-    Snapshots::createSingleSnapshotOfDefault(const SCD& scd)
+    Snapshots::createSingleSnapshotOfDefault(const SCD& scd, Plugins::Report& report)
     {
 	checkUserdata(scd.userdata);
 
@@ -709,12 +714,12 @@ namespace snapper
 	snapshot.cleanup = scd.cleanup;
 	snapshot.userdata = scd.userdata;
 
-	return createHelper(snapshot, end());
+	return createHelper(snapshot, end(), false, report);
     }
 
 
     Snapshots::iterator
-    Snapshots::createPreSnapshot(const SCD& scd)
+    Snapshots::createPreSnapshot(const SCD& scd, Plugins::Report& report)
     {
 	checkUserdata(scd.userdata);
 
@@ -725,12 +730,12 @@ namespace snapper
 	snapshot.cleanup = scd.cleanup;
 	snapshot.userdata = scd.userdata;
 
-	return createHelper(snapshot, getSnapshotCurrent());
+	return createHelper(snapshot, getSnapshotCurrent(), false, report);
     }
 
 
     Snapshots::iterator
-    Snapshots::createPostSnapshot(Snapshots::const_iterator pre, const SCD& scd)
+    Snapshots::createPostSnapshot(Snapshots::const_iterator pre, const SCD& scd, Plugins::Report& report)
     {
 	if (pre == entries.end() || pre->isCurrent() || pre->getType() != PRE ||
 	    findPost(pre) != entries.end())
@@ -746,18 +751,18 @@ namespace snapper
 	snapshot.cleanup = scd.cleanup;
 	snapshot.userdata = scd.userdata;
 
-	return createHelper(snapshot, getSnapshotCurrent());
+	return createHelper(snapshot, getSnapshotCurrent(), false, report);
     }
 
 
     Snapshots::iterator
-    Snapshots::createHelper(Snapshot& snapshot, const_iterator parent, bool empty)
+    Snapshots::createHelper(Snapshot& snapshot, const_iterator parent, bool empty, Plugins::Report& report)
     {
 	// parent == end indicates the btrfs default subvolume. Unclean, but
 	// adding a special snapshot like current needs too many API changes.
 
-	Hooks::create_snapshot(Hooks::Stage::PRE_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
-			       snapshot);
+	Plugins::create_snapshot(Plugins::Stage::PRE_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
+				 snapshot, report);
 
 	try
 	{
@@ -791,23 +796,23 @@ namespace snapper
 	    SN_RETHROW(e);
 	}
 
-	Hooks::create_snapshot(Hooks::Stage::POST_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
-			       snapshot);
+	Plugins::create_snapshot(Plugins::Stage::POST_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
+				 snapshot, report);
 
 	return entries.insert(entries.end(), snapshot);
     }
 
 
     void
-    Snapshots::modifySnapshot(iterator snapshot, const SMD& smd)
+    Snapshots::modifySnapshot(iterator snapshot, const SMD& smd, Plugins::Report& report)
     {
 	if (snapshot == entries.end() || snapshot->isCurrent())
 	    SN_THROW(IllegalSnapshotException());
 
 	checkUserdata(smd.userdata);
 
-	Hooks::modify_snapshot(Hooks::Stage::PRE_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
-			       *snapshot);
+	Plugins::modify_snapshot(Plugins::Stage::PRE_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
+				 *snapshot, report);
 
 	snapshot->description = smd.description;
 	snapshot->cleanup = smd.cleanup;
@@ -815,20 +820,20 @@ namespace snapper
 
 	snapshot->writeInfo();
 
-	Hooks::modify_snapshot(Hooks::Stage::POST_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
-			       *snapshot);
+	Plugins::modify_snapshot(Plugins::Stage::POST_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
+				 *snapshot, report);
     }
 
 
     void
-    Snapshots::deleteSnapshot(iterator snapshot)
+    Snapshots::deleteSnapshot(iterator snapshot, Plugins::Report& report)
     {
 	if (snapshot == entries.end() || snapshot->isCurrent() || snapshot->isDefault() ||
 	    snapshot->isActive())
 	    SN_THROW(IllegalSnapshotException());
 
-	Hooks::delete_snapshot(Hooks::Stage::PRE_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
-			       *snapshot);
+	Plugins::delete_snapshot(Plugins::Stage::PRE_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
+				 *snapshot, report);
 
 	snapshot->deleteFilesystemSnapshot();
 	snapshot->deleteFilelists();
@@ -839,8 +844,8 @@ namespace snapper
 	SDir infos_dir = snapper->openInfosDir();
 	infos_dir.unlink(decString(snapshot->getNum()), AT_REMOVEDIR);
 
-	Hooks::delete_snapshot(Hooks::Stage::POST_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
-			       *snapshot);
+	Plugins::delete_snapshot(Plugins::Stage::POST_ACTION, snapper->subvolumeDir(), snapper->getFilesystem(),
+				 *snapshot, report);
 
 	entries.erase(snapshot);
     }
